# HANDIE UTILS - HAM RADIO UTILITIES

This application is a simple utility to access different functions that may be of particular interest to POTA/SOTA Amateur Radio operators. This application is not glitzy, but provides the desired functionality of easy access to data of interest to portable operators. One of the goals for this app is that it could run without a need for Internet or cell service when it is used in the field. The only functions that require the Internet is Call Sign Lookup and the map display of home QTH. Since Call Sign Lookup is using XML data from qrz.com, it doesn't require the bandwidth that would be required by a full page render in a web browser, so it may be possible even with spotty cell service. The home QTH display does go to Safari for the map display, but there is a link back to Pythonista in the upper left corner of the screen in standard iOS convention.

This application is comprised of several Python scripts to perform the following functions :

- Park Lookup
- Summit Lookup
- Calculate Distance
- Coordinates Conversion
- Call Sign Lookup


## REQUIREMENTS

- The Python scripts in this package run only on an iOS platform
- The Pythonista app is required for run-time interpretation. This app is available from the App Store.
- It is necessary to have a qrz.com XML data subscription for Call Sign Lookup to function.
- The parks CSV file must be downloaded from [POTA](https://POTA.app). If you want to see personal stats for My Activations and My Hunter QSOs for park entities, make sure you are signed in on POTA.app so that your personal stats will be downloaded for display. An account is not a requirement for the download, though.
- The summits CSV file must be downloaded from [SOTA](https://www.SOTAdata.org.uk/en/)


## INSTALLATION

- The **handie_install_util** script is used to pull the current distribution from pypi. This script will be provided by George. Select the **Install Handie Utils Package & Copy CSV Files** option. This will put the Python scripts and .pyui files in the **src** folder under 
**Python Modules->site-packages** .
- If registered with qrz.com for XML data, then select the  **handie_install_util** option **Initialize Arctic Key File** to create the credentials file for qrz.com access.
- There is a shortcut available from George to quickly and easily access the **handie_install_util** script. This shortcut is name **Handie_Install**.
- There is also a shortcut available from George to quickly and easily access the **Handie Utils** application. This shortcut is name **Handie_Utils**.


## CONFIGURATION

- In iOS settings under **Privacy&Security - > Location Services** find Pythonista and select While Using.